"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const core_1 = require("@babel/core");
exports.default = (_babel, options = { scope: 'none' }) => {
    return {
        name: '@yookue/babel-plugin-remove-comment',
        visitor: {
            Program(path) {
                if (!options.scope || options.scope === 'none') {
                    return;
                }
                if (!['all', 'block', 'line', 'none'].includes(options.scope)) {
                    throw SyntaxError(`Invalid scope parameter '${options.scope}', it should be one of 'all' | 'block' | 'line' | 'none'`);
                }
                path.traverse({
                    enter(path) {
                        const leading = path.node.leadingComments;
                        const trailing = path.node.trailingComments;
                        if ((!leading || leading.length === 0) && (!trailing || trailing.length === 0)) {
                            return;
                        }
                        if (options.scope === 'all') {
                            core_1.types.removeComments(path.node);
                        }
                        else if (options.scope === 'block') {
                            if (leading && leading.length > 0) {
                                path.node.leadingComments = leading.filter(item => item.type !== 'CommentBlock');
                            }
                            if (trailing && trailing.length > 0) {
                                path.node.trailingComments = trailing.filter(item => item.type !== 'CommentBlock');
                            }
                        }
                        else if (options.scope === 'line') {
                            if (leading && leading.length > 0) {
                                path.node.leadingComments = leading.filter(item => item.type !== 'CommentLine');
                            }
                            if (trailing && trailing.length > 0) {
                                path.node.trailingComments = trailing.filter(item => item.type !== 'CommentLine');
                            }
                        }
                    }
                });
            }
        }
    };
};
